@@ -28,10 +28,15 @@ Initialise the QDarkStyleSheet module when used with python.
 This modules provides a function to transparently load the stylesheets
 with the correct rc file.
 """
-import os
+import logging
+import platform
 
 
-__version__ = "1.9"
+__version__ = "1.10"
+
+
+def _logger():
+    return logging.getLogger('qdarkstyle')
 
 
 def load_stylesheet(pyside=True):
@@ -56,9 +61,53 @@ def load_stylesheet(pyside=True):
 
     f = QFile(":qdarkstyle/style.qss")
     if not f.exists():
-        print("Unable to set stylesheet, file not found\n")
+        _logger().error("Unable to load stylesheet, file not found in "
+                        "resources")
         return ""
     else:
         f.open(QFile.ReadOnly | QFile.Text)
         ts = QTextStream(f)
-        return ts.readAll()
+        stylesheet = ts.readAll()
+        if platform.system().lower() == 'darwin':  # see issue #12 on github
+            mac_fix = '''
+            QDockWidget::title
+            {
+                background-color: #353434;
+            }
+            '''
+            stylesheet += mac_fix
+        return stylesheet
+
+
+def load_stylesheet_pyqt5():
+    """
+    Loads the stylesheet for use in a pyqt5 application.
+
+    :param pyside: True to load the pyside rc file, False to load the PyQt rc file
+
+    :return the stylesheet string
+    """
+    # Smart import of the rc file
+    import qdarkstyle.pyqt5_style_rc
+
+    # Load the stylesheet content from resources
+    from PyQt5.QtCore import QFile, QTextStream
+
+    f = QFile(":qdarkstyle/style.qss")
+    if not f.exists():
+        _logger().error("Unable to load stylesheet, file not found in "
+                        "resources")
+        return ""
+    else:
+        f.open(QFile.ReadOnly | QFile.Text)
+        ts = QTextStream(f)
+        stylesheet = ts.readAll()
+        if platform.system().lower() == 'darwin':  # see issue #12 on github
+            mac_fix = '''
+            QDockWidget::title
+            {
+                background-color: #353434;
+            }
+            '''
+            stylesheet += mac_fix
+        return stylesheet
\ No newline at end of file
